<?php
/**
 * IP2Location Country Blocker Plugin.
 *
 * @copyright  Copyright (C) 2018 - 2021 IP2Location.
 * @license    http://www.gnu.org/licenses/gpl-2.0.txt GNU General Public License Version 2 or Later
 */
defined('_JEXEC') or die;

use Joomla\CMS\Application\CMSApplication;
use Joomla\CMS\Plugin\CMSPlugin;
use Joomla\Plugin\System\Webauthn\Helper\Joomla;

class PlgSystemCountry_blocker extends CMSPlugin
{
	/**
	 * Application object.
	 *
	 * @var CMSApplication
	 */
	protected $app;

	/**
	 * The configuration as array.
	 *
	 * @var array
	 */
	protected $configurations = [];

	/**
	 * Listener for the `onAfterInitialise` event.
	 *
	 * @return void
	 */
	public function onAfterInitialise()
	{
		// Do not block the administrator page
		if (Joomla::isAdminPage()) {
			return;
		}

		$countryCode = $this->getCountryCodeByIp($this->getClientIp());
		$countryList = $this->params->get('blocked_countries');

		if ($countryCode == null) {
			return;
		}

		if (!is_array($countryList)) {
			return;
		}

		if (!in_array($countryCode, $countryList)) {
			return;
		}

		if ($this->params->get('mode') == 1) {
			$this->app->redirect($this->params->get('redirected_url'));

			return;
		}

		throw new \Exception($this->params->get('message'), 403);
	}

	private function getClientIp()
	{
		// For development purpose
		if (isset($_SERVER['DEV_MODE'])) {
			return '8.8.8.8';
		}

		if (isset($_SERVER['HTTP_CF_CONNECTING_IP']) && filter_var($_SERVER['HTTP_CF_CONNECTING_IP'], FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE)) {
			return $_SERVER['HTTP_CF_CONNECTING_IP'];
		}

		if (isset($_SERVER['X-Real-IP']) && filter_var($_SERVER['X-Real-IP'], FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE)) {
			return $_SERVER['X-Real-IP'];
		}

		if (isset($_SERVER['HTTP_X_FORWARDED_FOR'])) {
			$ip = trim(current(explode(',', $_SERVER['HTTP_X_FORWARDED_FOR'])));

			if (filter_var($ip, FILTER_VALIDATE_IP, FILTER_FLAG_NO_PRIV_RANGE | FILTER_FLAG_NO_RES_RANGE)) {
				return $ip;
			}
		}

		return $_SERVER['REMOTE_ADDR'];
	}

	private function getCountryCodeByIp($ip)
	{
		require_once JPATH_PLUGINS . '/system/country_blocker/vendor/autoload.php';

		if ($this->params->get('api_key')) {
			// Lookup by web service
			$service = new \IP2Location\WebService($this->params->get('api_key'));
			$result = $service->lookup($ip);

			return (isset($result['country_code'])) ? $result['country_code'] : null;
		}

		$files = scandir(JPATH_PLUGINS . '/system/country_blocker/bin');

		foreach ($files as $file) {
			if (strtoupper(substr($file, -4)) == '.BIN') {
				$database = new \IP2Location\Database((JPATH_PLUGINS . '/system/country_blocker/bin/' . $file), \IP2Location\Database::FILE_IO);

				// Get geolocation by IP address.
				$result = $database->lookup($ip, \IP2Location\Database::ALL);

				return $result['countryCode'];
			}
		}
	}
}
